Learn R Programming

ChemoSpec (version 2.0-2)

colLeaf: Color the Leaves of a Dendrogram

Description

This function colors the leaves of a dendrogram object. The code was taken from the help files. Not for end-user use.

Usage

colLeaf(n, spectra)

Arguments

Value

Returns a node with the label color properties set.

References

http://academic.depauw.edu/~hanson/ChemoSpec/ChemoSpec.html