ChemoSpec, the user may use any color name/format known to R. For ease of comparison, it would be nice to plan ahead and use the same color scheme for all your plots. However, a difficulty to bear in mind is that R plots are generally on a white background, so pale colors should be avoided, while GGobi, which is used by function plotScoresG, plots on a black background (interactively), so dark colors should be avoided. Hence some compromise is necessary.In addition to colors, "Spectra" objects also contain a list of symbols, and alternative symbols. These are useful for plotting in black and white, or when color-blind individuals will be viewing the plots. The alternative symbols are simply lower-case letters, as these are needed for plotScoresRGL, which cannot plot traditional symbols.
If you plan to use rggobi and GGobi to view the data later, keep in mind that ggobi only uses certain color schemes (although there are many options) and in interactive operation plots on a black background. In the case of ChemoSpec, two particular options have been hard-coded into the function plotScoresG for simplicity. If you plan to use plotScoresG, you may wish to choose from one of these two color schemes before you begin if you want all your graphics to use the same scheme. Keep in mind that these colors must be used in order (though you can use the order of argument gr.crit to associate a particular group with a particular color:
primary scheme: c("red3", "dodgerblue4", "forestgreen",
"purple4", "orangered", "yellow", "orangered4", "violetred2")
pastel scheme: c("seagreen", "brown2", "skyblue2", "hotpink3",
"chartreuse3", "darkgoldenrod2", "lightsalmon3", "gray48")
If you want to see what these colors look like, use display.brewer.pal(8, "Set1") or display.brewer.pal(8, "Set2").
Finally, the current color scheme of a "Spectra" object may be determined using sumGroups or changed using conColScheme. Also, splitSpectraGroups has another means of changing the color scheme but this is intended for the situations when you are creating new categories for your samples.