gr.crit in the file names of .csv files and assigns group membership. Also assigns a color, a symbol and an alternate symbol to each group. Warnings are given if there are file names that don't match entries in gr.crit or there are entries in gr.crit that don't match any file names. Not intended for users.groupNcolor(spectra, gr.crit = NULL, gr.cols = c("auto"))"Spectra". Until this function acts on spectra it is not quite complete.files2SpectraObjectfiles2SpectraObject"Spectra". Until this function has done its job, an object of class "Spectra" will not pass checks as the assembly is not complete (see chkSpectra).)files2SpectraObject for details; sumGroups to see the outcome.