Learn R Programming

ChemoSpec (version 1.61-2)

hcaScores: HCA on PCA scores from a Spectra Object

Description

A wrapper which performs HCA on the scores from a PCA of a "Spectra" object, color-coding the results as specified in the object.

Usage

hcaScores(spectra, pca, title = "no title provided",
	scores = c(1:5), c.method = "complete",
	d.method = "euclidean", use.sym = FALSE, ...)

Arguments

Value

None. Side effect is a plot.

Rdversion

1.1

References

http://academic.depauw.edu/~hanson/ChemoSpec/ChemoSpec.html

See Also

hclust for the underlying function. See hcaSpectra for HCA of the entire data set stored in the "Spectra" object. plotHCA for the function that actually does the plotting.

Examples

Run this code
data(SrE.IR)
results <- classPCA(SrE.IR, choice = "noscale")
hcaScores(SrE.IR,  results, scores = c(1:5), title = "Serenoa repends IR Spectra")

Run the code above in your browser using DataLab