Learn R Programming

ChemoSpec (version 2.0-2)

shrinkLeaf: Shrink the Leaves of a Dendrogram

Description

This function shrinks the size of leaves of a dendrogram object. The code was taken from the help files. Not for end-user use.

Usage

shrinkLeaf(n, spectra)

Arguments

Value

Returns a node with the label size properties set.

References

http://academic.depauw.edu/~hanson/ChemoSpec/ChemoSpec.html