Learn R Programming

ChemoSpec (version 2.0-2)

ChemoSpec-package: Exploratory Chemometrics for Spectroscopy

Description

A collection of functions for plotting spectra (NMR, IR etc) and carrying out various forms of top-down exploratory data analysis, such as HCA, PCA and model-based clustering. The design permits comparison of data from samples which fall into groups such as treatment vs. control. Robust methods appropriate for this type of high-dimensional data are available. ChemoSpec is designed to be very user friendly and suitable for people with limited background in R. A vignette illustrating typical operations is available.

Arguments

Rdversion

1.1

docType

package

Details

ll{ Package: ChemoSpec Type: Package Version: 2.0-2 Date: 2014-05-31 License: GPL-3 }

References

http://academic.depauw.edu/~hanson/ChemoSpec/ChemoSpec.html