Learn R Programming

ChemoSpec (version 1.51-2)

aovPCAscores: Conduct PCA and plot aovPCA Scores of a Spectra Object

Description

Uses the results from aovPCA to conduct PCA and plot the scores.

Usage

aovPCAscores(spectra, LM, plot = 1, type = "class", choice = NULL, ...)

Arguments

Value

Returns the PCA results, and creates the requested plot.

Details

Argument plot is used to select a matrix from those in LM. The residual error matrix is then added to the selected matrix before performing PCA. Use names(LM) to see which factor is stored in which matrix.

References

Harrington, et. al 2005, Pinto, et. al 2008.

See Also

The use of this function can be seen in aovPCA. See also plotScores.