Learn R Programming

ChemoSpec (version 2.0-2)

aovPCAscores: Conduct PCA and plot aovPCA Scores of a Spectra Object

Description

Uses the results from aovPCA to conduct PCA and plot the scores.

Usage

aovPCAscores(spectra, LM, plot = 1, type = "class", choice = NULL, ...)

Arguments

Value

Returns the PCA results, and creates the requested plot.

Details

Argument plot is used to select a matrix from those in LM. The residual error matrix is then added to the selected matrix before performing PCA. Use names(LM) to see which factor is stored in which matrix.

References

Pinto, Bosc, Nocairi, Barros, and Rutledge. "Using ANOVA-PCA for Discriminant Analysis: ..." Analytica Chimica Acta 629.1-2 (2008): 47-55.

Harrington, Vieira, Espinoza, Nien, Romero, and Yergey. "Analysis of Variance--Principal Component Analysis: ..." Analytica Chimica Acta 544.1-2 (2005): 118-27.

See Also

The use of this function can be seen in aovPCA. See also plotScores.