Uses the results from aov_pcaSpectra to conduct PCA and plot
the scores.
Argument plot is used to select a matrix from those in LM.
The residual error matrix is then added to the selected matrix before
performing PCA. Use names(LM) to see which factor is stored in which
matrix.
aovPCAscores(spectra, LM, plot = 1, type = "class", choice = NULL, ...)An object of S3 class Spectra.
List of matrices created by aov_pcaSpectra.
An integer specifying which scores to plot.
Either classical ("cls") or robust ("rob"); Results in either
c_pcaSpectra or r_pcaSpectra being called on the
Spectra object.
The type of scaling to be performed. See
c_pcaSpectra and r_pcaSpectra for details.
Additional parameters to be passed to plotScores.
For example, you can plot confidence ellipses this way. Note that ellipses
are drawn based on the groups in spectra$groups, but the separation
done by aov_pcaSpectra is based on argument fac. These may
not correspond, but you can edit spectra$groups to match if necessary.
Returns the PCA results, and creates the requested plot.
Pinto, Bosc, Nocairi, Barros, and Rutledge. "Using ANOVA-PCA for Discriminant Analysis: ..." Analytica Chimica Acta 629.1-2 (2008): 47-55.
Harrington, Vieira, Espinoza, Nien, Romero, and Yergey. "Analysis of Variance--Principal Component Analysis: ..." Analytica Chimica Acta 544.1-2 (2005): 118-27.
The use of this function can be seen in
aov_pcaSpectra. See also plotScores.
Additional documentation at https://bryanhanson.github.io/ChemoSpec/