aov_pcaSpectra to conduct PCA and plot the scores.aovPCAscores(spectra, LM, plot = 1, type = "class", choice = NULL, ...)Spectra.aov_pcaSpectra.c_pcaSpectra or r_pcaSpectra being called on the c_pcaSpectra and r_pcaSpectra for details.plotScores.plot is used to select a matrix from those in LM. The residual error matrix is then added to the selected matrix before performing PCA. Use names(LM) to see which factor is stored in which matrix.Harrington, Vieira, Espinoza, Nien, Romero, and Yergey. "Analysis of Variance--Principal Component Analysis: ..." Analytica Chimica Acta 544.1-2 (2005): 118-27.
aov_pcaSpectra. See also plotScores.