baselineSpec: Carry out baseline correction on a Spectra object
Description
This function is a simple wrapper to functions in package baseline which carries out a variety of baseline correction routines.
Usage
baselineSpec(Spectra, int = TRUE, retC = FALSE, ...)
Arguments
Value
If int = FALSE, an interactive plot is created. If int = FALSE and retC = FALSE, an object of class baseline is returned (see baseline-class. If int = FALSE and retC = TRUE, a Spectra object containing the corrected spectra is returned. In these latter two cases plots are also drawn.
Details
In the plots, the x axis ticks give the data point index, not the original values from your data.