colLeaf: Color the Leaves of a Dendrogram
Description
This function colors the leaves of a dendrogram object. The code was taken from the help files. Not for end-user use.Value
Returns a node with the label color properties set.References
http://academic.depauw.edu/~hanson/ChemoSpec/ChemoSpec.html