In ChemoSpec, the user may use any color name/format known to R. For
ease of comparison, it would be nice to plan ahead and use the same color
scheme for all your plots. The current color scheme of a
Spectra object may be determined using sumGroups
or changed using conColScheme. Also,
splitSpectraGroups has another means of changing the color
scheme, but this is intended for the situations when you are creating new
categories/groups for your samples.