getMaxCovByFreq: Order Rows of a Covariance Matrix by Absolute Value
Description
Given a covariance matrix, the maximum absolute value of each row is computed. The results are ordered, and optionally, limited to values greater than a particular value.
Numeric. A value in the interval (0...1) giving the quantile to be selected. For instance, Quan = 0.1 selects the top 10 percent of the absolute covariance values.
Value
A data frame containing the frequencies from the Spectra object, the covariance at that frequency, the absolute value of the covariance, and the relative covariance. Sorted by absolute covariance in descending order.
Details
IMPORTANT: The current version includes the variances along the diagonal and thus the answers are skewed. A future version will include the ability to exclude these values from the analysis.