getMaxCovByFreq: Order Rows of a Covariance Matrix by Absolute Value
Description
Given a covariance matrix, the maximum absolute value of each row is computed. The results are ordered, and optionally, limited to values greater than a particular value.
Numeric. A value in the interval (0...1) giving the quantile to be selected. For instance, Quan = 0.1 selects the top 10 percent of values.
Value
A data frame containing the frequencies from the Spectra object, the absolute value of the covariance at that frequency, and the relative covariance. Sorted by absolute covariance in descending order.