Learn R Programming

ChemoSpec (version 2.0-2)

hcaScores: HCA on PCA scores from a Spectra Object

Description

A wrapper which performs HCA on the scores from a PCA of a "Spectra" object, color-coding the results as specified in the object.

Usage

hcaScores(spectra, pca, scores = c(1:5), c.method = "complete",
	d.method = "euclidean", use.sym = FALSE, ...)

Arguments

Value

An object of class dendrogram. Side effect is a plot.

Rdversion

1.1

References

http://academic.depauw.edu/~hanson/ChemoSpec/ChemoSpec.html

See Also

hclust for the underlying function. See hcaSpectra for HCA of the entire data set stored in the "Spectra" object. plotHCA for the function that actually does the plotting.

Examples

Run this code
data(SrE.IR)
results <- classPCA(SrE.IR, choice = "noscale")
myt <- expression(bolditalic(Serenoa)~bolditalic(repens)~bold(IR~Spectra))
hcaScores(SrE.IR,  results, scores = c(1:5), main = myt)

Run the code above in your browser using DataLab