shrinkLeaf: Shrink the Leaves of a Dendrogram Based on a Spectra Object
Description
This function shrinks the size of leaves of a dendrogram object. The code was taken from the help files. An internal function, not generally called by the user.Usage
shrinkLeaf(n, spectra)
Value
Returns a node with the label size properties set.References
https://github.com/bryanhanson/ChemoSpec