sortCrossPeaks(spectra, V = NULL, window = NULL, Quan = NULL,
byFreq = FALSE, freqThres = 0.01, ...)Spectra.cov(spectra$data)..NULL, the default, approximately 10 percent of the points are removed.Quan = 0.1 selects the top 10 percent of the returned values.Quan != NULL. Frequencies closer than freqThres will be collapsed and replaced with their average.Quan != NULL and byFreq = TRUE. Frequencies closer than freqThres will be collapsed and replaced with their average.verbose = TRUE which will pass through to collapseRowsOrCols and give information about which rows and columns which are collapsed if Quan != NULLSpectra object, the maximum covariance at that frequency, the absolute value of the maximum covariance, and the relative absolute maximum covariance.If the data were sorted by frequency without selecting the top values (i.e. Quan = NULL), there would be no point in collapsing the values as they are all equally spaced. But when you have selected the top covariance values, the frequencies are no longer consecutive and equally spaced, so collapsing them replaces trivially close values with their averages.
data(metMUD1)
V <- cov(metMUD1$data)
# Look at the top 1%
res <- sortCrossPeaks(metMUD1, V, Quan = 0.01)
resRun the code above in your browser using DataLab