specSurvey: Plot Measures of Central Tendency and Spread for a Spectra Object
Description
This function computes and plots various measures of central tendency and spread for a "Spectra" object. Several different measures/spreads are available. The computation can be done by group or using the entire data set.
Usage
specSurvey(spectra, method = c("sd", "sem", "sem95", "mad", "iqr"),
by.gr = TRUE, title = "no title provided", ...)